@@ -36,7 +36,12 @@ class MailerBase: Enums
         void sendMail(std::string const &command, std::string const &label, 
                       std::string const &recipient, bool dontSend);
 
-        std::string headers() const;
+        std::string headers(
+                void (*processHeaders)(std::string &, std::string const &)
+                           ) const;
+
+        static bool contentHeader(char const *headerCp);
+        static std::string cleanupHeader(std::string const &hdr);
 };
         
 inline std::string const &MailerBase::subject() const
