@@ -2,7 +2,7 @@
 
 void Remailer::checkRelax()
 {
-    if (d_arg.option(0, "relax"))
+    if (d_preamble.arg.option(0, "relax"))
         d_log << level(LOGDEFAULT) << 
                 "--relax ignored. Use `--umask' instead\n";
 }
