@@ -19,20 +19,41 @@ void Remailer::copyToBoundary(ostream &out, istream &in)
     string *line1 = &line[0];
     string *line2 = &line[1];
 
-    getline(in, *line1);
+    char sep[] = "\r\n";                    // assume CRLF separator
+    bool ignore1 = true;
 
-    while (getline(in, *line2))
+    getline(in, *line1);                    // get the first line
+
+    if (line1->back() == '\r')              // indeed: CRLF
+        line->pop_back();                   // so: remove the CR fm the line
+    else if (in.peek() == '\r')             // if it's LFCR?
     {
-        if (line2->find(d_boundary) == 0)   // boundary was found
-        {
-            out << *line1;                  // insert line 1
-            return;
-        }
-        out << *line1 << endl;              // otherwise insert line1 + \n
-
-        swap(line1, line2);                 // and prepare a new line1 
+        in.ignore();                        // then remove the CR
+        swap(sep[0], sep[1]);               // and swap the separator
+    }
+    else
+    {
+        sep[1] = 0;                         // only \n: that's the separator
+        ignore1 = false;                    // only 1 separating character
     }
 
+
+    while (getline(in, *line2, sep[0]))     // get the next line
+    {
+        if (ignore1)
+            in.ignore();
+
+        if (line2->find(d_boundary) == 0)   // boundary was found
+        {
+            out << *line1;                  // insert the last line w/o the
+            return;                         // last separator
+        }
+        out << *line1 << sep;               // otherwise insert line1 + \n
+        swap(line1, line2);                 // and prepare a new line1 
+    }
+        
     throw LogException() << "no " << d_boundary << 
                 " boundary separator found in multipart MIME file\n";
 }
+
+
