@@ -12,8 +12,9 @@ Remailer::~Remailer()
     unlink(d_errName.c_str());
     unlink(d_mailName.c_str());
     unlink(d_multipartSignedDataName.c_str());
-    unlink(d_orgName.c_str());
+    unlink(d_contentsName.c_str());
     unlink(d_reencryptName.c_str());
     unlink(d_reencryptedName.c_str());
     unlink(d_signatureName.c_str());
+    unlink(d_hdrsName.c_str());
 }
