@@ -2,7 +2,9 @@
 
 void Remailer::setReplyTo()
 {
-    ConfigFile::const_iterator iter = d_config.findRE(R"(^\s*replyTo:)");
+    ConfigFile::const_iterator iter = 
+                            d_config.findRE(R"(^\s*replyTo:)");
+
     if (iter != d_config.end())
     {
         d_replyTo = String::trim(*iter);
