@@ -1,9 +1,21 @@
 #include "remailer.ih"
 
+// Simple pgp encrypted file (near line 410 in gpg-remailer(1))
+// Format:
+// ----------------------------------------------------------------------
+// Content-Type: text/plain; charset=us-ascii
+// Content-Disposition: inline
+// Content-Transfer-Encoding: quoted-printable
+// 
+// decrypted text of the message
+// ----------------------------------------------------------------------
+
+
 void Remailer::simple(IOContext &io)
 {
-    d_log << level(LOGDEBUG) << "No boundary, no multipart message\n";
-    
+    d_log << level(LOGDEBUG) << 
+                "Simple mail received: No boundary, no multipart message\n";
+
     // if no boundary and the first line is a content-type then 
     // insert those lines first
     if (io.line.find("Content-Type:") == 0)
@@ -22,12 +34,3 @@ void Remailer::simple(IOContext &io)
                     io.decrypted.rdbuf();
 }
 
-// Simple pgp encrypted file.
-// Format:
-// ----------------------------------------------------------------------
-// Content-Type: text/plain; charset=us-ascii
-// Content-Disposition: inline
-// Content-Transfer-Encoding: quoted-printable
-// 
-// decrypted text of the message
-// ----------------------------------------------------------------------
